Module com.networknt.basic.auth
Package com.networknt.basic
-
Class Summary Class Description BasicAuthHandler This is a middleware handler that handles basic authentication in restful APIs.BasicConfig
| Class | Description |
|---|---|
| BasicAuthHandler |
This is a middleware handler that handles basic authentication in restful APIs.
|
| BasicConfig |